@@ -1,20 +1,10 @@
-/*************************************************************************
- *  Copyright (C) 2009, 2010 by Volker Lanz <vl@fidra.de>                *
- *  Copyright (C) 2016, 2017 by Andrius Štikonas <andrius@stikonas.eu>   *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2014-2020 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2018 Abhijeet Sharma <sharma.abhijeet2096@gmail.com>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "gui/editmountpointdialogwidget.h"
 #include "gui/editmountoptionsdialog.h"
@@ -174,7 +164,7 @@ void EditMountPointDialogWidget::buttonSelectClicked(bool)
 
 void EditMountPointDialogWidget::removeMountPoint()
 {
-    for (auto it = fstabEntries().begin(); it != fstabEntries().end(); ) {
+    for (auto it = fstabEntries().begin(); it != fstabEntries().end(); ++it) {
         if (editPath().count() <= 1 && (
                 (it->fsSpec().contains(partition().deviceNode()) && !partition().deviceNode().isEmpty() ) ||
                 (it->fsSpec().contains(partition().fileSystem().uuid()) && !partition().fileSystem().uuid().isEmpty() ) ||
@@ -185,7 +175,7 @@ void EditMountPointDialogWidget::removeMountPoint()
             fstabEntries().erase(it);
             partition().setMountPoint(QString());
         }
-        else if (editPath().count() > 1 && ((&*it == currentEntry)))
+        else if (editPath().count() > 1 && (&*it == currentEntry))
         {
             fstabEntries().erase(it);
             editPath().removeItem(editPath().currentIndex());
