@@ -1,21 +1,14 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2009, 2010, 2012 by Volker Lanz <vl@fidra.de>    *
- *  Copyright (C) 2015 by Teo Mrnjavac <teo@kde.org>                     *
- *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2012 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2014-2020 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2016 Chantara Tith <tith.chantara@gmail.com>
+    SPDX-FileCopyrightText: 2018 Caio Jordão Carvalho <caiojcarvalho@gmail.com>
+    SPDX-FileCopyrightText: 2018 René J.V. Bertin <rjvbertin@gmail.com>
+    SPDX-FileCopyrightText: 2018 Huzaifa Faruqui <huzaifafaruqui@gmail.com>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "gui/mainwindow.h"
 #include "gui/infopane.h"
@@ -50,6 +43,7 @@
 #include <ops/backupoperation.h>
 #include <ops/restoreoperation.h>
 #include <ops/checkoperation.h>
+#include <ops/setpartflagsoperation.h>
 
 #include <fs/filesystem.h>
 #include <fs/filesystemfactory.h>
@@ -80,7 +74,6 @@
 #include <KActionCollection>
 #include <KMessageBox>
 #include <KAboutData>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KXMLGUIFactory>
 #include <KJobUiDelegate>
@@ -137,7 +130,6 @@ void MainWindow::init()
     loadConfig();
 
     show();
-    ExternalCommand::setParentWidget(this);
     pmWidget().init(&operationStack());
 
     scanDevices();
@@ -165,7 +157,6 @@ void MainWindow::closeEvent(QCloseEvent* event)
     saveConfig();
 
     KXmlGuiWindow::closeEvent(event);
-    ExternalCommand::stopHelper();
     delete m_ApplyProgressDialog;
 }
 
@@ -202,7 +193,7 @@ void MainWindow::setupActions()
     undoOperation->setToolTip(xi18nc("@info:tooltip", "Undo the last operation"));
     undoOperation->setStatusTip(xi18nc("@info:status", "Remove the last operation from the list."));
     actionCollection()->setDefaultShortcut(undoOperation, QKeySequence(Qt::CTRL + Qt::Key_Z));
-    undoOperation->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")).pixmap(IconSize(KIconLoader::Toolbar)));
+    undoOperation->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
 
     QAction* clearAllOperations = actionCollection()->addAction(QStringLiteral("clearAllOperations"));
     connect(clearAllOperations, &QAction::triggered, this, &MainWindow::onClearAllOperations);
@@ -210,7 +201,7 @@ void MainWindow::setupActions()
     clearAllOperations->setText(xi18nc("@action:inmenu clear the list of operations", "Clear"));
     clearAllOperations->setToolTip(xi18nc("@info:tooltip", "Clear all operations"));
     clearAllOperations->setStatusTip(xi18nc("@info:status", "Empty the list of pending operations."));
-    clearAllOperations->setIcon(QIcon::fromTheme(QStringLiteral("dialog-cancel")).pixmap(IconSize(KIconLoader::Toolbar)));
+    clearAllOperations->setIcon(QIcon::fromTheme(QStringLiteral("dialog-cancel")));
 
     QAction* applyAllOperations = actionCollection()->addAction(QStringLiteral("applyAllOperations"));
     connect(applyAllOperations, &QAction::triggered, this, &MainWindow::onApplyAllOperations);
@@ -218,7 +209,7 @@ void MainWindow::setupActions()
     applyAllOperations->setText(xi18nc("@action:inmenu apply all operations", "Apply"));
     applyAllOperations->setToolTip(xi18nc("@info:tooltip", "Apply all operations"));
     applyAllOperations->setStatusTip(xi18nc("@info:status", "Apply the pending operations in the list."));
-    applyAllOperations->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")).pixmap(IconSize(KIconLoader::Toolbar)));
+    applyAllOperations->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok-apply")));
 
     // Device actions
     QAction* createNewPartitionTable = actionCollection()->addAction(QStringLiteral("createNewPartitionTable"));
@@ -228,7 +219,7 @@ void MainWindow::setupActions()
     createNewPartitionTable->setToolTip(xi18nc("@info:tooltip", "Create a new partition table"));
     createNewPartitionTable->setStatusTip(xi18nc("@info:status", "Create a new and empty partition table on a device."));
     actionCollection()->setDefaultShortcut(createNewPartitionTable, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_N));
-    createNewPartitionTable->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear")).pixmap(IconSize(KIconLoader::Toolbar)));
+    createNewPartitionTable->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear")));
 
     QAction* exportPartitionTable = actionCollection()->addAction(QStringLiteral("exportPartitionTable"));
     connect(exportPartitionTable, &QAction::triggered, this, &MainWindow::onExportPartitionTable);
@@ -236,7 +227,7 @@ void MainWindow::setupActions()
     exportPartitionTable->setText(xi18nc("@action:inmenu", "Export Partition Table"));
     exportPartitionTable->setToolTip(xi18nc("@info:tooltip", "Export a partition table"));
     exportPartitionTable->setStatusTip(xi18nc("@info:status", "Export the device's partition table to a text file."));
-    exportPartitionTable->setIcon(QIcon::fromTheme(QStringLiteral("document-export")).pixmap(IconSize(KIconLoader::Toolbar)));
+    exportPartitionTable->setIcon(QIcon::fromTheme(QStringLiteral("document-export")));
 
     QAction* importPartitionTable = actionCollection()->addAction(QStringLiteral("importPartitionTable"));
     connect(importPartitionTable, &QAction::triggered, this, &MainWindow::onImportPartitionTable);
@@ -244,7 +235,7 @@ void MainWindow::setupActions()
     importPartitionTable->setText(xi18nc("@action:inmenu", "Import Partition Table"));
     importPartitionTable->setToolTip(xi18nc("@info:tooltip", "Import a partition table"));
     importPartitionTable->setStatusTip(xi18nc("@info:status", "Import a partition table from a text file."));
-    importPartitionTable->setIcon(QIcon::fromTheme(QStringLiteral("document-import")).pixmap(IconSize(KIconLoader::Toolbar)));
+    importPartitionTable->setIcon(QIcon::fromTheme(QStringLiteral("document-import")));
 
     QAction* removeVolumeGroup = actionCollection()->addAction(QStringLiteral("removeVolumeGroup"));
     connect(removeVolumeGroup, &QAction::triggered, this, &MainWindow::onRemoveVolumeGroup);
@@ -254,7 +245,7 @@ void MainWindow::setupActions()
     removeVolumeGroup->setToolTip(i18nc("@info:tooltip", "Remove selected Volume Group"));
     removeVolumeGroup->setStatusTip(i18nc("@info:status", "Remove selected Volume Group."));
     //actionCollection()->setDefaultShortcut(removeVolumeGroup, QKeySequence(/*SHORTCUT KEY HERE*/));
-    removeVolumeGroup->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")).pixmap(IconSize(KIconLoader::Toolbar)));
+    removeVolumeGroup->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
 
     QAction* resizeVolumeGroup = actionCollection()->addAction(QStringLiteral("resizeVolumeGroup"));
     connect(resizeVolumeGroup, &QAction::triggered, this, &MainWindow::onResizeVolumeGroup);
@@ -264,7 +255,7 @@ void MainWindow::setupActions()
     resizeVolumeGroup->setToolTip(i18nc("@info:tooltip", "Resize selected Volume Group"));
     resizeVolumeGroup->setStatusTip(i18nc("@info:status", "Extend or reduce selected Volume Group."));
     //actionCollection()->setDefaultShortcut(resizeVolumeGroup, QKeySequence(/*SHORTCUT KEY HERE*/));
-    resizeVolumeGroup->setIcon(QIcon::fromTheme(QStringLiteral("arrow-right-double")).pixmap(IconSize(KIconLoader::Toolbar)));
+    resizeVolumeGroup->setIcon(QIcon::fromTheme(QStringLiteral("arrow-right-double")));
 
     QAction* deactivateVolumeGroup = actionCollection()->addAction(QStringLiteral("deactivateVolumeGroup"));
     connect(deactivateVolumeGroup, &QAction::triggered, this, &MainWindow::onDeactivateVolumeGroup);
@@ -273,7 +264,7 @@ void MainWindow::setupActions()
     deactivateVolumeGroup->setText(i18nc("@action:inmenu", "Deactivate Volume Group"));
     deactivateVolumeGroup->setToolTip(i18nc("@info:tooltip", "Deactivate selected Volume Group"));
     deactivateVolumeGroup->setStatusTip(i18nc("@info:status", "Deactivate selected Volume Group before unplugging removable devices."));
-    deactivateVolumeGroup->setIcon(QIcon::fromTheme(QStringLiteral("media-eject")).pixmap(IconSize(KIconLoader::Toolbar)));
+    deactivateVolumeGroup->setIcon(QIcon::fromTheme(QStringLiteral("media-eject")));
 
     QAction* smartStatusDevice = actionCollection()->addAction(QStringLiteral("smartStatusDevice"));
     connect(smartStatusDevice, &QAction::triggered, this, &MainWindow::onSmartStatusDevice);
@@ -288,7 +279,7 @@ void MainWindow::setupActions()
     propertiesDevice->setText(xi18nc("@action:inmenu", "Properties"));
     propertiesDevice->setToolTip(xi18nc("@info:tooltip", "Show device properties dialog"));
     propertiesDevice->setStatusTip(xi18nc("@info:status", "View and modify device properties"));
-    propertiesDevice->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")).pixmap(IconSize(KIconLoader::Toolbar)));
+    propertiesDevice->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
 
     // Partition actions
     QAction* newPartition = actionCollection()->addAction(QStringLiteral("newPartition"));
@@ -298,7 +289,7 @@ void MainWindow::setupActions()
     newPartition->setToolTip(xi18nc("@info:tooltip", "New partition"));
     newPartition->setStatusTip(xi18nc("@info:status", "Create a new partition."));
     actionCollection()->setDefaultShortcut(newPartition, QKeySequence(Qt::CTRL + Qt::Key_N));
-    newPartition->setIcon(QIcon::fromTheme(QStringLiteral("document-new")).pixmap(IconSize(KIconLoader::Toolbar)));
+    newPartition->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
 
     QAction* resizePartition = actionCollection()->addAction(QStringLiteral("resizePartition"));
     connect(resizePartition, &QAction::triggered, &pmWidget(), &PartitionManagerWidget::onResizePartition);
@@ -307,7 +298,7 @@ void MainWindow::setupActions()
     resizePartition->setToolTip(xi18nc("@info:tooltip", "Resize or move partition"));
     resizePartition->setStatusTip(xi18nc("@info:status", "Shrink, grow or move an existing partition."));
     actionCollection()->setDefaultShortcut(resizePartition, QKeySequence(Qt::CTRL + Qt::Key_R));
-    resizePartition->setIcon(QIcon::fromTheme(QStringLiteral("arrow-right-double")).pixmap(IconSize(KIconLoader::Toolbar)));
+    resizePartition->setIcon(QIcon::fromTheme(QStringLiteral("arrow-right-double")));
 
     QAction* deletePartition = actionCollection()->addAction(QStringLiteral("deletePartition"));
     connect(deletePartition, &QAction::triggered, &pmWidget(), &PartitionManagerWidget::onDeletePartition);
@@ -316,7 +307,7 @@ void MainWindow::setupActions()
     deletePartition->setToolTip(xi18nc("@info:tooltip", "Delete partition"));
     deletePartition->setStatusTip(xi18nc("@info:status", "Delete a partition."));
     actionCollection()->setDefaultShortcut(deletePartition, QKeySequence::Delete);
-    deletePartition->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")).pixmap(IconSize(KIconLoader::Toolbar)));
+    deletePartition->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
 
     QAction* shredPartition = actionCollection()->addAction(QStringLiteral("shredPartition"));
     connect(shredPartition, &QAction::triggered, &pmWidget(), &PartitionManagerWidget::onShredPartition);
@@ -325,7 +316,7 @@ void MainWindow::setupActions()
     shredPartition->setToolTip(xi18nc("@info:tooltip", "Shred partition"));
     shredPartition->setStatusTip(xi18nc("@info:status", "Shred a partition so that its contents cannot be restored."));
     actionCollection()->setDefaultShortcut(shredPartition, QKeySequence(Qt::SHIFT + Qt::Key_Delete));
-    shredPartition->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete-shred")).pixmap(IconSize(KIconLoader::Toolbar)));
+    shredPartition->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete-shred")));
 
     QAction* copyPartition = actionCollection()->addAction(QStringLiteral("copyPartition"));
     connect(copyPartition, &QAction::triggered, &pmWidget(), &PartitionManagerWidget::onCopyPartition);
@@ -334,7 +325,7 @@ void MainWindow::setupActions()
     copyPartition->setToolTip(xi18nc("@info:tooltip", "Copy partition"));
     copyPartition->setStatusTip(xi18nc("@info:status", "Copy an existing partition."));
     actionCollection()->setDefaultShortcut(copyPartition, QKeySequence(Qt::CTRL + Qt::Key_C));
-    copyPartition->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")).pixmap(IconSize(KIconLoader::Toolbar)));
+    copyPartition->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
 
     QAction* pastePartition = actionCollection()->addAction(QStringLiteral("pastePartition"));
     connect(pastePartition, &QAction::triggered, &pmWidget(), &PartitionManagerWidget::onPastePartition);
@@ -343,7 +334,7 @@ void MainWindow::setupActions()
     pastePartition->setToolTip(xi18nc("@info:tooltip", "Paste partition"));
     pastePartition->setStatusTip(xi18nc("@info:status", "Paste a copied partition."));
     actionCollection()->setDefaultShortcut(pastePartition, QKeySequence(Qt::CTRL + Qt::Key_V));
-    pastePartition->setIcon(QIcon::fromTheme(QStringLiteral("edit-paste")).pixmap(IconSize(KIconLoader::Toolbar)));
+    pastePartition->setIcon(QIcon::fromTheme(QStringLiteral("edit-paste")));
 
     QAction* editMountPoint = actionCollection()->addAction(QStringLiteral("editMountPoint"));
     connect(editMountPoint, &QAction::triggered, &pmWidget(), &PartitionManagerWidget::onEditMountPoint);
@@ -372,7 +363,7 @@ void MainWindow::setupActions()
     checkPartition->setText(xi18nc("@action:inmenu", "Check"));
     checkPartition->setToolTip(xi18nc("@info:tooltip", "Check partition"));
     checkPartition->setStatusTip(xi18nc("@info:status", "Check a filesystem on a partition for errors."));
-    checkPartition->setIcon(QIcon::fromTheme(QStringLiteral("flag")).pixmap(IconSize(KIconLoader::Toolbar)));
+    checkPartition->setIcon(QIcon::fromTheme(QStringLiteral("flag")));
 
     QAction* propertiesPartition = actionCollection()->addAction(QStringLiteral("propertiesPartition"));
     connect(propertiesPartition, &QAction::triggered, &pmWidget(), &PartitionManagerWidget::onPropertiesPartition);
@@ -380,7 +371,7 @@ void MainWindow::setupActions()
     propertiesPartition->setText(xi18nc("@action:inmenu", "Properties"));
     propertiesPartition->setToolTip(xi18nc("@info:tooltip", "Show partition properties dialog"));
     propertiesPartition->setStatusTip(xi18nc("@info:status", "View and modify partition properties (label, partition flags, etc.)"));
-    propertiesPartition->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")).pixmap(IconSize(KIconLoader::Toolbar)));
+    propertiesPartition->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
 
     QAction* backup = actionCollection()->addAction(QStringLiteral("backupPartition"));
     connect(backup, &QAction::triggered, &pmWidget(), &PartitionManagerWidget::onBackupPartition);
@@ -388,7 +379,7 @@ void MainWindow::setupActions()
     backup->setText(xi18nc("@action:inmenu", "Backup"));
     backup->setToolTip(xi18nc("@info:tooltip", "Backup partition"));
     backup->setStatusTip(xi18nc("@info:status", "Backup a partition to an image file."));
-    backup->setIcon(QIcon::fromTheme(QStringLiteral("document-export")).pixmap(IconSize(KIconLoader::Toolbar)));
+    backup->setIcon(QIcon::fromTheme(QStringLiteral("document-export")));
 
     QAction* restore = actionCollection()->addAction(QStringLiteral("restorePartition"));
     connect(restore, &QAction::triggered, &pmWidget(), &PartitionManagerWidget::onRestorePartition);
@@ -396,7 +387,7 @@ void MainWindow::setupActions()
     restore->setText(xi18nc("@action:inmenu", "Restore"));
     restore->setToolTip(xi18nc("@info:tooltip", "Restore partition"));
     restore->setStatusTip(xi18nc("@info:status", "Restore a partition from an image file."));
-    restore->setIcon(QIcon::fromTheme(QStringLiteral("document-import")).pixmap(IconSize(KIconLoader::Toolbar)));
+    restore->setIcon(QIcon::fromTheme(QStringLiteral("document-import")));
 
     // Tools actions
     QAction* createVolumeGroup = actionCollection()->addAction(QStringLiteral("createVolumeGroup"));
@@ -406,7 +397,7 @@ void MainWindow::setupActions()
     createVolumeGroup->setToolTip(i18nc("@info:tooltip", "Create a new LVM Volume Group"));
     createVolumeGroup->setStatusTip(i18nc("@info:status", "Create a new LVM Volume Group as a device."));
     actionCollection()->setDefaultShortcut(createVolumeGroup, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_L));
-    createVolumeGroup->setIcon(QIcon::fromTheme(QStringLiteral("document-new")).pixmap(IconSize(KIconLoader::Toolbar)));
+    createVolumeGroup->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
 
     QAction* fileSystemSupport = actionCollection()->addAction(QStringLiteral("fileSystemSupport"));
     connect(fileSystemSupport, &QAction::triggered, this, &MainWindow::onFileSystemSupport);
@@ -420,7 +411,7 @@ void MainWindow::setupActions()
     refreshDevices->setToolTip(xi18nc("@info:tooltip", "Refresh all devices"));
     refreshDevices->setStatusTip(xi18nc("@info:status", "Renew the devices list."));
     actionCollection()->setDefaultShortcut(refreshDevices, Qt::Key_F5);
-    refreshDevices->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")).pixmap(IconSize(KIconLoader::Toolbar)));
+    refreshDevices->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
 
     // Settings Actions
     actionCollection()->addAction(QStringLiteral("toggleDockDevices"), dockDevices().toggleViewAction());
@@ -436,14 +427,14 @@ void MainWindow::setupActions()
     clearLog->setText(xi18nc("@action:inmenu", "Clear Log"));
     clearLog->setToolTip(xi18nc("@info:tooltip", "Clear the log output"));
     clearLog->setStatusTip(xi18nc("@info:status", "Clear the log output panel."));
-    clearLog->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-list")).pixmap(IconSize(KIconLoader::Toolbar)));
+    clearLog->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear-list")));
 
     QAction* saveLog = actionCollection()->addAction(QStringLiteral("saveLog"));
     connect(saveLog, &QAction::triggered, &treeLog(), &TreeLog::onSaveLog);
     saveLog->setText(xi18nc("@action:inmenu", "Save Log"));
     saveLog->setToolTip(xi18nc("@info:tooltip", "Save the log output"));
     saveLog->setStatusTip(xi18nc("@info:status", "Save the log output to a file."));
-    saveLog->setIcon(QIcon::fromTheme(QStringLiteral("document-save")).pixmap(IconSize(KIconLoader::Toolbar)));
+    saveLog->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
 
     // Help Actions
     QAction* aboutKPMcore = actionCollection()->addAction(QStringLiteral("aboutKPMcore"));
@@ -451,7 +442,7 @@ void MainWindow::setupActions()
     aboutKPMcore->setText(xi18nc("@action:inmenu", "About KPMcore Library"));
     aboutKPMcore->setToolTip(xi18nc("@info:tooltip", "Show About KPMcore dialog"));
     aboutKPMcore->setStatusTip(xi18nc("@info:status", "Show About KPMcore dialog."));
-    aboutKPMcore->setIcon(QIcon::fromTheme(QStringLiteral("partitionmanager")).pixmap(IconSize(KIconLoader::Toolbar)));
+    aboutKPMcore->setIcon(QIcon::fromTheme(QStringLiteral("partitionmanager")));
 }
 
 void MainWindow::setupConnections()
@@ -992,7 +983,7 @@ void MainWindow::onImportPartitionTable()
                 return;
             }
 
-            if (tableType != PartitionTable::msdos && tableType != PartitionTable::gpt) {
+            if (tableType != PartitionTable::msdos && tableType != PartitionTable::gpt && tableType != PartitionTable::none) {
                 KMessageBox::error(this, xi18nc("@info", "Partition table type \"%1\" is not supported for import (line %2).", reType.captured(1), lineNo), xi18nc("@title:window", "Error While Importing Partition Table"));
                 return;
             }
@@ -1064,9 +1055,13 @@ void MainWindow::onImportPartitionTable()
             if (fs->supportSetLabel() != FileSystem::cmdSupportNone && !volumeLabel.isEmpty())
                 fs->setLabel(volumeLabel);
 
-            Partition* p = new Partition(parent, device, role, fs, firstSector, lastSector, QString(), PartitionTable::flagsFromList(flags), QString(), false, PartitionTable::flagsFromList(flags), Partition::State::New);
+            Partition* p = new Partition(parent, device, role, fs, firstSector, lastSector, QString(), PartitionTable::Flag::None, QString(), false, PartitionTable::Flag::None, Partition::State::New);
 
             operationStack().push(new NewOperation(device, p));
+
+            auto newFlags = PartitionTable::flagsFromList(flags);
+            if (newFlags != PartitionTable::Flag::None)
+                operationStack().push(new SetPartFlagsOperation(device, *p, newFlags));
         } else
             Log(Log::Level::warning) << xi18nc("@info:status", "Could not parse line %1 from import file. Ignoring it.", lineNo);
     }
@@ -1192,7 +1187,7 @@ void MainWindow::onSettingsChanged()
 
     PartitionAlignment::setSectorAlignment(Config::sectorAlignment());
 
-    emit settingsChanged();
+    Q_EMIT settingsChanged();
 }
 
 void MainWindow::onConfigureOptions()
